# -*- coding: utf-8 -*-
"""
Filename: __init__.py
Author: Iliya Vereshchagin
Copyright (c) 2023. All rights reserved.

Created: 12.09.2023
Last Modified: 12.09.2023

Description:
This file contains module init
"""
from .openai_python_api.chatgpt import ChatGPT
from .openai_python_api.dalle import DALLE
